@@ -10,6 +10,9 @@ from llmling_agent_cli.chat import chat_command
 from llmling_agent_cli.history import history_cli
 from llmling_agent_cli.quickstart import quickstart_command
 from llmling_agent_cli.run import run_command
+from llmling_agent_cli.serve import serve_command
+from llmling_agent_cli.task import task_command
+from llmling_agent_cli.watch import watch_command
 
 
 MAIN_HELP = "🤖 LLMling Agent CLI - Run and manage LLM agents"
@@ -27,6 +30,10 @@ cli.command(name="list")(list_agents)
 cli.command(name="set")(set_active_file)
 cli.command(name="chat")(chat_command)
 cli.command(name="quickstart")(quickstart_command)
+cli.command(name="watch")(watch_command)
+cli.command(name="serve")(serve_command)
+cli.command(name="task")(task_command)
+
 cli.add_typer(history_cli, name="history")
 
 try:
