@@ -7,8 +7,8 @@ import shutil
 from llmling.cli.constants import output_format_opt, verbose_opt
 from llmling.cli.utils import format_output
 import typer as t
-from upath import UPath
 
+from llmling_agent.utils.inspection import validate_import
 from llmling_agent_cli import agent_store, resolve_agent_config
 
 
@@ -32,7 +32,10 @@ def init_agent_config(
     automatically registered and set as active.
     """
     # Create config
+    from upath import UPath
+
     if interactive:
+        validate_import("promptantic", "chat")
         from promptantic import ModelGenerator
 
         from llmling_agent.models import AgentsManifest
@@ -109,10 +112,7 @@ def list_agents(
         # Load and validate agent definition
         agent_def = AgentsManifest.from_file(config_path)
         # Set the name field from the dict key for each agent
-        agents = [
-            agent.model_copy(update={"name": name})
-            for name, agent in agent_def.agents.items()
-        ]
+        agents = [ag.model_copy(update={"name": n}) for n, ag in agent_def.agents.items()]
         format_output(agents, output_format)
 
     except t.Exit:
